@@ -1,8 +1,10 @@
+from operator import eq
 from typing import Sequence
 
 from reprit.base import generate_repr
 
 from ground import hints
+from .hints import Domain
 
 
 class Point:
@@ -48,6 +50,9 @@ class Multipoint:
 
     __repr__ = generate_repr(__init__)
 
+    def __eq__(self, other: 'Multipoint') -> bool:
+        return are_sequences_equivalent(self.points, other.points)
+
     @property
     def points(self) -> Sequence[hints.Point]:
         return self._points
@@ -84,6 +89,9 @@ class Multisegment:
 
     __repr__ = generate_repr(__init__)
 
+    def __eq__(self, other: 'Multisegment') -> bool:
+        return are_sequences_equivalent(self.segments, other.segments)
+
     @property
     def segments(self) -> Sequence[hints.Segment]:
         return self._segments
@@ -97,6 +105,9 @@ class Contour:
 
     __repr__ = generate_repr(__init__)
 
+    def __eq__(self, other: 'Contour') -> bool:
+        return are_sequences_equivalent(self.vertices, other.vertices)
+
     @property
     def vertices(self) -> Sequence[hints.Polygon]:
         return self._vertices
@@ -147,6 +158,10 @@ class Polygon:
 
     __repr__ = generate_repr(__init__)
 
+    def __eq__(self, other: 'Polygon') -> bool:
+        return (self.border == other.border
+                and are_sequences_equivalent(self.holes, other.holes))
+
     @property
     def border(self) -> hints.Contour:
         return self._border
@@ -164,6 +179,14 @@ class Multipolygon:
 
     __repr__ = generate_repr(__init__)
 
+    def __eq__(self, other: 'Multipolygon') -> bool:
+        return are_sequences_equivalent(self.polygons, other.polygons)
+
     @property
     def polygons(self) -> Sequence[hints.Polygon]:
         return self._polygons
+
+
+def are_sequences_equivalent(left: Sequence[Domain],
+                             right: Sequence[Domain]) -> bool:
+    return len(left) == len(right) and all(map(eq, left, right))
