@@ -95,16 +95,20 @@ def relate(cross_product: QuaternaryPointFunction,
                 else Relation.COMPONENT)
     elif test_start == goal_end or test_end == goal_start:
         return Relation.TOUCH
-    elif (goal_start < test_start < goal_end
-          or test_start < goal_start < test_end):
-        return Relation.OVERLAP
+    elif goal_start < test_start < goal_end:
+        return (Relation.COMPONENT
+                if test_end < goal_end
+                else Relation.OVERLAP)
+    elif test_start < goal_start < test_end:
+        return (Relation.COMPOSITE
+                if goal_end < test_end
+                else Relation.OVERLAP)
     else:
         return Relation.DISJOINT
 
 
 def _bounding_box_contains(start: Point, end: Point, point: Point) -> bool:
-    start_x, start_y = start.x, start.y
-    end_x, end_y = end.x, end.y
-    x_min, x_max = (start_x, end_x) if start_x < end_x else (end_x, start_x)
-    y_min, y_max = (start_y, end_y) if start_y < end_y else (end_y, start_y)
-    return x_min <= point.x <= x_max and y_min <= point.y <= y_max
+    start_x, start_y, end_x, end_y = start.x, start.y, end.x, end.y
+    min_x, max_x = (start_x, end_x) if start_x < end_x else (end_x, start_x)
+    min_y, max_y = (start_y, end_y) if start_y < end_y else (end_y, start_y)
+    return min_x <= point.x <= max_x and min_y <= point.y <= max_y
